package cn.iocoder.yudao.module.order.controller.admin.cons;

import cn.iocoder.yudao.framework.common.exception.ServiceException;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.util.code.CodeUtils;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.mybatis.core.query.LambdaQueryWrapperX;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import cn.iocoder.yudao.module.customer.dal.dataobject.customer.CustomerDO;
import cn.iocoder.yudao.module.customer.dal.dataobject.customerContacts.CustomerContactsDO;
import cn.iocoder.yudao.module.customer.service.customer.CustomerService;
import cn.iocoder.yudao.module.customer.service.customerContacts.CustomerContactsService;
import cn.iocoder.yudao.module.depository.dal.mysql.warehouse.WarehouseLineMapper;
import cn.iocoder.yudao.module.depository.dto.LogisticsInfoDto;
import cn.iocoder.yudao.module.order.convert.cons.ConsConvert;
import cn.iocoder.yudao.module.order.dal.dataobject.cons.ConsDO;
import cn.iocoder.yudao.module.order.dal.dataobject.consMedia.ConsMediaDO;
import cn.iocoder.yudao.module.order.service.cons.ConsService;
import cn.iocoder.yudao.module.order.service.consItem.ConsItemService;
import cn.iocoder.yudao.module.order.service.consLocation.ConsLocationService;
import cn.iocoder.yudao.module.order.service.consMedia.ConsMediaService;
import cn.iocoder.yudao.module.order.vo.cons.*;
import cn.iocoder.yudao.module.order.vo.consApproval.ConsRetiredWarehouseCreateReqVO;
import cn.iocoder.yudao.module.order.vo.consItem.ConsItemBackVO;
import cn.iocoder.yudao.module.order.vo.consItem.ConsItemQueryVO;
import cn.iocoder.yudao.module.order.vo.consLocation.ConsLocationUpdateReqVO;
import cn.iocoder.yudao.module.order.vo.order.OrderBackVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.EXPORT;


@Validated
@RestController
@Api(tags = "管理后台 - 集运包裹主")
@RequestMapping("/ecw/cons")
public class ConsController {

    @Resource
    private ConsService consService;

    @Resource
    private CustomerContactsService customerContactsService;

    @Resource
    private ConsMediaService consentMediaService;

    @Resource
    private CustomerService customerService;

    @Resource
    private WarehouseLineMapper warehouseLineMapper;

    @Resource
    private ConsItemService consItemService;

    @Resource
    private ConsLocationService consLocationService;

    @PostMapping("/create")
    @ApiOperation("创建集运包裹主")
    @PreAuthorize("@ss.hasPermission('ecw:cons:create')")
    public CommonResult<Long> createCons(@Valid @RequestBody ConsCreateReqVO createReqVO) {
        return success(consService.createCons(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新集运包裹主")
    @PreAuthorize("@ss.hasPermission('ecw:cons:update')")
    public CommonResult<Boolean> updateCons(@Valid @RequestBody ConsUpdateReqVO updateReqVO) {
        consService.updateCons(updateReqVO);
        return success(true);
    }

    @PutMapping("/updateInspect")
    @ApiOperation("更新集运包裹主")
    @PreAuthorize("@ss.hasPermission('ecw:cons:update')")
    public CommonResult<Boolean> updateInspect(@Valid @RequestBody ConsUpdateReqVO updateReqVO) {
        consService.updateConsInspect(updateReqVO);
        return success(true);
    }

    @PutMapping("/updateConsBatchSignOff")
    @ApiOperation("批量签收集运包裹")
    @PreAuthorize("@ss.hasPermission('ecw:cons:update')")
    public CommonResult<Boolean> updateConsBatchSignOff(@Valid @RequestBody ConsUpdateBatchReqVO updateReqVO) {
        consService.updateConsSign(updateReqVO);
        return success(true);
    }

    @PutMapping("/updateConsBatch")
    @ApiOperation("批量修改集运包裹")
    @PreAuthorize("@ss.hasPermission('ecw:cons:update')")
    public CommonResult<Boolean> updateConsBatch(@Valid @RequestBody ConsUpdateBatchReqVO updateReqVO) {
        consService.updateConsBatch(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除集运包裹主")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('ecw:cons:delete')")
    public CommonResult<Boolean> deleteCons(@RequestParam("id") Long id) {
        consService.deleteCons(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得集运包裹主")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('ecw:cons:query')")
    public CommonResult<ConsBackVO> getCons(@RequestParam("id") Long id) {
        ConsBackVO consById = consService.getConsById(id);
        return success(consById);
    }

    @GetMapping("/list")
    @ApiOperation("获得集运包裹主列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    @PreAuthorize("@ss.hasPermission('ecw:cons:query')")
    public CommonResult<List<ConsBackVO>> getConsList(@RequestParam("ids") Collection<Long> ids) {
        List<ConsDO> list = consService.getConsList(ids);
        return success(ConsConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得集运包裹主分页")
    @PreAuthorize("@ss.hasPermission('ecw:cons:query')")
    public CommonResult<PageResult<ConsBackVO>> getConsPage(@Valid ConsQueryVO query, PageVO page) {
        PageResult<ConsBackVO> pageResult = consService.getConsPage(query, page);
        return success(pageResult);
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出集运包裹主 Excel")
    @PreAuthorize("@ss.hasPermission('ecw:cons:export')")
    @OperateLog(type = EXPORT)
    public void exportConsExcel(@Valid ConsQueryVO query,
                                HttpServletResponse response) throws IOException {
        List<ConsDO> list = consService.getConsList(query);
        // 导出 Excel
        List<ConsBackVO> datas = ConsConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "集运包裹主.xls", "数据", ConsBackVO.class, datas);
    }


    @GetMapping("/courier/number")
    @ApiOperation("生成快递单号")
    public CommonResult<String> getCourierNumber() {
        String courierNumberByCons = CodeUtils.getCourierNumberByCons();
        //判断生成的快递单号是否重复，重复重新生成
        while (consService.selectOne("express_no", courierNumberByCons) != null) {
            courierNumberByCons = CodeUtils.getCourierNumberByCons();
        }
        return success(courierNumberByCons);
    }

    @PostMapping("/createPad")
    @ApiOperation("创建集运包裹主")
    public CommonResult<Boolean> createPad(@Valid @RequestBody ConsCreateReqVO createReqVO) {
        consService.createPad(createReqVO);
        return success(true);
    }

    @GetMapping("/getTempOrderByConsIds")
    @ApiOperation("创建转运临时order对象")
    public CommonResult<OrderBackVO> getTempOrderByConsIds(@RequestParam("ids") Collection<Long> ids) {
        OrderBackVO tempOrderByConsIds = consService.getTempOrderByConsIds(ids);
        return CommonResult.success(tempOrderByConsIds);
    }

    @GetMapping("/getPad")
    @ApiOperation("获得集运包裹主")
    public CommonResult<ConsBackVO> getPad(Long id, String expressNo) {
        if (id == null && StringUtils.isBlank(expressNo)) {
            throw new ServiceException(500, "参数错误");
        }
        ConsDO cons = consService.selectOne(new LambdaQueryWrapperX<ConsDO>()
                .eq(id != null, ConsDO::getId, id)
                .eq(StringUtils.isNotBlank(expressNo), ConsDO::getExpressNo, expressNo));
        if (cons == null) {
            return success(null);
        }
        CustomerDO customer = customerService.selectOne("id", cons.getCustomerId());
        CustomerContactsDO customerContacts = customerContactsService.getDefaultContacts(cons.getCustomerId());
        List<ConsItemBackVO> consItemBacks = consItemService.getConsItemBackVOList(new ConsItemQueryVO().setConsId(cons.getId()));
        ConsBackVO consBackVO = ConsConvert.INSTANCE.convert(cons);
        consBackVO.setConsItemVOList(consItemBacks);
        if (customerContacts != null) {
            consBackVO.setAreaCode(customerContacts.getAreaCode());
            consBackVO.setPhoneNew(customerContacts.getPhoneNew());
        }
        if (customer != null) {
            consBackVO.setCustomerName(customer.getName());
        }

        List<ConsLocationUpdateReqVO> consLocationBackList = consLocationService.getConsLocationListByConsId(cons.getId());
        consBackVO.setConsLocationBackList(consLocationBackList == null ? new ArrayList<>() : consLocationBackList);

        //获取签收图片
        ConsMediaDO consMedia = consentMediaService.getOne(new LambdaQueryWrapperX<ConsMediaDO>().eq(ConsMediaDO::getConsId, cons.getId())
                .eq(ConsMediaDO::getBizId, cons.getId())
                .eq(ConsMediaDO::getMediaBusinessType, 3));
        consBackVO.setMediaUrl(consMedia == null ? "" : consMedia.getMediaUrl());
        // 物流信息查询
        LogisticsInfoDto initialLogisticsInfoDto =
                warehouseLineMapper.getStartInfoAndDestInfoByLineId(cons.getWarehouseLineId());
        //初始物流信息
        consBackVO.setInitialLogisticsInfoDto(initialLogisticsInfoDto);
        return success(consBackVO);
    }

    @PutMapping("/signedPda")
    @ApiOperation("签收PDA")
    public CommonResult<Boolean> signedPda(@Valid @RequestBody ConsUpdateReqVO updateReqVO) {
        consService.signedPda(updateReqVO);
        return success(true);
    }

    @PostMapping("/createConsRetiredWarehouseApplication")
    @ApiOperation("集运包裹退仓")
    @PreAuthorize("@ss.hasPermission('ecw:cons:create')")
    public CommonResult<Boolean> createConsRetiredWarehouseApplication(@RequestBody ConsRetiredWarehouseCreateReqVO query) {
        consService.createConsRetiredWarehouseApplication(query);
        return success(true);
    }

    @PostMapping("/createConsExitApplication")
    @ApiOperation("集运包裹撤出")
    @PreAuthorize("@ss.hasPermission('ecw:cons:create')")
    public CommonResult<Boolean> createConsExitApplication(@RequestBody ConsRetiredWarehouseCreateReqVO query) {
        consService.createConsExitApplication(query);
        return success(true);
    }


    @PostMapping("/editAndUpdateConsRetiredWarehouseDeal")
    @ApiOperation("集运包裹退仓处理保存")
    @PreAuthorize("@ss.hasPermission('ecw:cons:create')")
    public CommonResult<Boolean> editAndUpdateConsRetiredWarehouseDeal(@RequestBody ConsRetiredWarehouseCreateReqVO query) {
        consService.editAndUpdateConsRetiredWarehouseDeal(query);
        return success(true);
    }
}
