package cn.iocoder.yudao.module.order.controller.admin.cons;

import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.order.convert.consInspectionDetails.ConsInspectionDetailsConvert;
import cn.iocoder.yudao.module.order.dal.dataobject.consInspectionDetails.ConsInspectionDetailsDO;
import cn.iocoder.yudao.module.order.service.consInspectionDetails.ConsInspectionDetailsService;
import cn.iocoder.yudao.module.order.vo.consInspectionDetails.ConsInspectionDetailsBackVO;
import cn.iocoder.yudao.module.order.vo.consInspectionDetails.ConsInspectionDetailsCreateReqVO;
import cn.iocoder.yudao.module.order.vo.consInspectionDetails.ConsInspectionDetailsQueryVO;
import cn.iocoder.yudao.module.order.vo.consInspectionDetails.ConsInspectionDetailsUpdateReqVO;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

import org.springframework.validation.annotation.Validated;
import io.swagger.annotations.*;

import javax.validation.*;
import java.util.*;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

@Validated
@RestController
@Api(tags = "管理后台 - 集运验货明细")
@RequestMapping("/ecw/cons-inspection-details")
public class ConsInspectionDetailsController {

    @Resource
    private ConsInspectionDetailsService consInspectionDetailsService;

    @PostMapping("/create")
    @ApiOperation("创建集运验货明细")
    public CommonResult<Long> createConsInspectionDetails(@RequestBody ConsInspectionDetailsCreateReqVO createReqVO) {
        return success(consInspectionDetailsService.createConsInspectionDetails(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新集运验货明细")
    public CommonResult<Boolean> updateConsInspectionDetails(@Valid @RequestBody ConsInspectionDetailsUpdateReqVO updateReqVO) {
        consInspectionDetailsService.updateConsInspectionDetails(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除集运验货明细")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<Boolean> deleteConsInspectionDetails(@RequestParam("id") Long id) {
        consInspectionDetailsService.deleteConsInspectionDetails(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得集运验货明细")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<ConsInspectionDetailsBackVO> getConsInspectionDetails(@RequestParam("id") Long id) {
        ConsInspectionDetailsDO consInspectionDetails = consInspectionDetailsService.getConsInspectionDetails(id);
        return success(ConsInspectionDetailsConvert.INSTANCE.convert(consInspectionDetails));
    }

    @GetMapping("/list")
    @ApiOperation("获得集运验货明细列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    public CommonResult<List<ConsInspectionDetailsBackVO>> getConsInspectionDetailsList(@RequestParam("ids") Collection<Long> ids) {
        List<ConsInspectionDetailsDO> list = consInspectionDetailsService.getConsInspectionDetailsList(ids);
        return success(ConsInspectionDetailsConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得集运验货明细分页")
    public CommonResult<PageResult<ConsInspectionDetailsBackVO>> getConsInspectionDetailsPage(@Valid ConsInspectionDetailsQueryVO query, PageVO page) {
        PageResult<ConsInspectionDetailsDO> pageResult = consInspectionDetailsService.getConsInspectionDetailsPage(query, page);
        return success(ConsInspectionDetailsConvert.INSTANCE.convertPage(pageResult));
    }

}
