package cn.iocoder.yudao.module.order.controller.admin.consApproval;

import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.order.convert.consApproval.ConsApprovalConvert;
import cn.iocoder.yudao.module.order.convert.consFee.ConsFeeConvert;
import cn.iocoder.yudao.module.order.dal.dataobject.consApproval.ConsApprovalDO;
import cn.iocoder.yudao.module.order.service.consApproval.ConsApprovalService;
import cn.iocoder.yudao.module.order.vo.consApproval.ConsApprovalBackVO;
import cn.iocoder.yudao.module.order.vo.consApproval.ConsApprovalCreateReqVO;
import cn.iocoder.yudao.module.order.vo.consApproval.ConsApprovalQueryVO;
import cn.iocoder.yudao.module.order.vo.consApproval.ConsApprovalUpdateReqVO;
import cn.iocoder.yudao.module.order.vo.consFee.ConsFeeBackVO;
import cn.iocoder.yudao.module.order.vo.consFee.ConsFeeQueryVO;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;
import javax.validation.constraints.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;

@Validated
@RestController
@Api(tags = "管理后台 - 集运包裹审批内容")
@RequestMapping("/ecw/cons-approval")
public class ConsApprovalController {

    @Resource
    private ConsApprovalService consApprovalService;

    @PostMapping("/create")
    @ApiOperation("创建集运包裹审批内容")
    public CommonResult<Long> createConsApproval(@Valid @RequestBody ConsApprovalCreateReqVO createReqVO) {
        return success(consApprovalService.createConsApproval(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新集运包裹审批内容")
    public CommonResult<Boolean> updateConsApproval(@Valid @RequestBody ConsApprovalUpdateReqVO updateReqVO) {
        consApprovalService.updateConsApproval(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除集运包裹审批内容")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<Boolean> deleteConsApproval(@RequestParam("id") Long id) {
        consApprovalService.deleteConsApproval(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得集运包裹审批内容")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<ConsApprovalBackVO> getConsApproval(@RequestParam("id") Long id) {
        ConsApprovalDO consApproval = consApprovalService.getConsApproval(id);
        return success(ConsApprovalConvert.INSTANCE.convert(consApproval));
    }

    @GetMapping("/cancelApplyAndUpdate")
    @ApiOperation("获得集运包裹审批内容")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<Boolean> cancelApplyAndUpdate(@RequestParam("id") Long id) {
        consApprovalService.cancelApplyAndUpdate(id);
        return success(true);
    }

    @GetMapping("/getConsApprovalList")
    @ApiOperation("获得集运包裹审批内容列表")
    public CommonResult<List<ConsApprovalBackVO>> getConsApprovalList(ConsApprovalQueryVO query) {
        List<ConsApprovalDO> list = consApprovalService.getConsApprovalList(query);
        return success(ConsApprovalConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得集运包裹审批内容分页")
    public CommonResult<PageResult<ConsApprovalBackVO>> getConsApprovalPage(@Valid ConsApprovalQueryVO query, PageVO page) {
        PageResult<ConsApprovalDO> pageResult = consApprovalService.getConsApprovalPage(query, page);
        return success(ConsApprovalConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出集运包裹审批内容 Excel")
    @OperateLog(type = EXPORT)
    public void exportConsApprovalExcel(@Valid ConsApprovalQueryVO query,
              HttpServletResponse response) throws IOException {
        List<ConsApprovalDO> list = consApprovalService.getConsApprovalList(query);
        // 导出 Excel
        List<ConsApprovalBackVO> datas = ConsApprovalConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "集运包裹审批内容.xls", "数据", ConsApprovalBackVO.class, datas);
    }
}
