package cn.iocoder.yudao.module.order.controller.admin.consException;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.order.convert.consException.ConsExceptionConvert;
import cn.iocoder.yudao.module.order.dal.dataobject.consException.ConsExceptionDO;
import cn.iocoder.yudao.module.order.service.consException.ConsExceptionService;
import cn.iocoder.yudao.module.order.vo.consException.ConsExceptionBackVO;
import cn.iocoder.yudao.module.order.vo.consException.ConsExceptionCreateReqVO;
import cn.iocoder.yudao.module.order.vo.consException.ConsExceptionQueryVO;
import cn.iocoder.yudao.module.order.vo.consException.ConsExceptionUpdateReqVO;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;

@Validated
@RestController
@Api(tags = "管理后台 - 集运异常")
@RequestMapping("/ecw/cons-exception")
public class ConsExceptionController {

    @Resource
    private ConsExceptionService consExceptionService;

    @PostMapping("/create")
    @ApiOperation("创建集运异常")
    public CommonResult<Long> createConsException(@Valid @RequestBody ConsExceptionCreateReqVO createReqVO) {
        return success(consExceptionService.createConsException(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新集运异常")
    public CommonResult<Boolean> updateConsException(@Valid @RequestBody ConsExceptionUpdateReqVO updateReqVO) {
        consExceptionService.updateConsException(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除集运异常")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<Boolean> deleteConsException(@RequestParam("id") Long id) {
        consExceptionService.deleteConsException(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得集运异常")
    public CommonResult<ConsExceptionBackVO> getConsException(ConsExceptionQueryVO query) {
        return success(consExceptionService.getConsException(query));
    }

    @GetMapping("/list")
    @ApiOperation("获得集运异常列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    public CommonResult<List<ConsExceptionBackVO>> getConsExceptionList(@RequestParam("ids") Collection<Long> ids) {
        List<ConsExceptionDO> list = consExceptionService.getConsExceptionList(ids);
        return success(ConsExceptionConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得集运异常分页")
    public CommonResult<PageResult<ConsExceptionBackVO>> getConsExceptionPage(@Valid ConsExceptionQueryVO query, PageVO page) {
        PageResult<ConsExceptionDO> pageResult = consExceptionService.getConsExceptionPage(query, page);
        return success(ConsExceptionConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出集运异常 Excel")
    @OperateLog(type = EXPORT)
    public void exportConsExceptionExcel(@Valid ConsExceptionQueryVO query,
              HttpServletResponse response) throws IOException {
        List<ConsExceptionDO> list = consExceptionService.getConsExceptionList(query);
        // 导出 Excel
        List<ConsExceptionBackVO> datas = ConsExceptionConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "集运异常.xls", "数据", ConsExceptionBackVO.class, datas);
    }
}
