package cn.iocoder.yudao.module.order.controller.admin.consFee;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.idempotent.core.annotation.Idempotent;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.order.convert.consFee.ConsFeeConvert;
import cn.iocoder.yudao.module.order.dal.dataobject.consFee.ConsFeeDO;
import cn.iocoder.yudao.module.order.service.consFee.ConsFeeService;
import cn.iocoder.yudao.module.order.vo.consFee.ConsFeeBackVO;
import cn.iocoder.yudao.module.order.vo.consFee.ConsFeeCreateReqVO;
import cn.iocoder.yudao.module.order.vo.consFee.ConsFeeQueryVO;
import cn.iocoder.yudao.module.order.vo.consFee.ConsFeeUpdateReqVO;
import cn.iocoder.yudao.module.order.vo.orderFeeApplication.OrderFeeBatchApplicationUpdateReqVO;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;

import javax.validation.*;
import javax.servlet.http.*;
import java.text.MessageFormat;
import java.util.*;
import java.io.IOException;
import java.util.concurrent.TimeUnit;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.error;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;

import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;
import static cn.iocoder.yudao.module.order.enums.ErrorCodeConstants.ORDER_FEE_APPLICATION_REPEAT_COMMIT;


@Validated
@RestController
@Api(tags = "管理后台 - 包裹费用")
@RequestMapping("/ecw/cons-fee")
public class ConsFeeController {

    @Resource
    private ConsFeeService consFeeService;

    @PostMapping("/create")
    @ApiOperation("创建包裹费用")
    public CommonResult<Long> createConsFee(@Valid @RequestBody ConsFeeCreateReqVO createReqVO) {
        return success(consFeeService.createConsFee(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新包裹费用")
    public CommonResult<Boolean> updateConsFee(@Valid @RequestBody ConsFeeUpdateReqVO updateReqVO) {
        consFeeService.updateConsFee(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除包裹费用")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<Boolean> deleteConsFee(@RequestParam("id") Long id) {
        consFeeService.deleteConsFee(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得包裹费用")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<ConsFeeBackVO> getConsFee(@RequestParam("id") Long id) {
        ConsFeeDO consFee = consFeeService.getConsFee(id);
        return success(ConsFeeConvert.INSTANCE.convert(consFee));
    }

    @GetMapping("/list")
    @ApiOperation("获得包裹费用列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    public CommonResult<List<ConsFeeBackVO>> getConsFeeList(@RequestParam("ids") Collection<Long> ids) {
        List<ConsFeeDO> list = consFeeService.getConsFeeList(ids);
        return success(ConsFeeConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/getConsFeeList")
    @ApiOperation("获得包裹费用")
    public CommonResult<List<ConsFeeBackVO>> getConsFeeList(@Valid ConsFeeQueryVO query) {
        return success(ConsFeeConvert.INSTANCE.convertList(consFeeService.getConsFeeList(query)));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出包裹费用 Excel")
    @OperateLog(type = EXPORT)
    public void exportConsFeeExcel(@Valid ConsFeeQueryVO query,
                                   HttpServletResponse response) throws IOException {
        List<ConsFeeDO> list = consFeeService.getConsFeeList(query);
        // 导出 Excel
        List<ConsFeeBackVO> datas = ConsFeeConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "包裹费用.xls", "数据", ConsFeeBackVO.class, datas);
    }

    @PostMapping("/create/batch")
    @ApiOperation("批量创建集运订单费用申请")
    @Idempotent(timeout = 10)
    public CommonResult<Boolean> createFeeBatchApplication(@RequestBody ConsFeeCreateReqVO createReqVO) throws Exception {
        consFeeService.createFeeBatchApplication(createReqVO);
        return success(true);
    }
}
