package cn.iocoder.yudao.module.order.controller.admin.consFollowup;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.order.convert.consFollowup.ConsFollowupConvert;
import cn.iocoder.yudao.module.order.dal.dataobject.consFollowup.ConsFollowupDO;
import cn.iocoder.yudao.module.order.service.consFollowup.ConsFollowupService;
import cn.iocoder.yudao.module.order.vo.consFollowup.ConsFollowupBackVO;
import cn.iocoder.yudao.module.order.vo.consFollowup.ConsFollowupCreateReqVO;
import cn.iocoder.yudao.module.order.vo.consFollowup.ConsFollowupQueryVO;
import cn.iocoder.yudao.module.order.vo.consFollowup.ConsFollowupUpdateReqVO;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;

import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;

import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;

@Validated
@RestController
@Api(tags = "管理后台 - 操作跟进")
@RequestMapping("/ecw/cons-followup")
public class ConsFollowupController {

    @Resource
    private ConsFollowupService consFollowupService;

    @PostMapping("/create")
    @ApiOperation("创建操作跟进")
    @PreAuthorize("@ss.hasPermission('ecw:cons-followup:create')")
    public CommonResult<Long> createConsFollowup(@Valid @RequestBody ConsFollowupCreateReqVO createReqVO) {
        return success(consFollowupService.createConsFollowup(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新操作跟进")
    @PreAuthorize("@ss.hasPermission('ecw:cons-followup:update')")
    public CommonResult<Boolean> updateConsFollowup(@Valid @RequestBody ConsFollowupUpdateReqVO updateReqVO) {
        consFollowupService.updateConsFollowup(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除操作跟进")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('ecw:cons-followup:delete')")
    public CommonResult<Boolean> deleteConsFollowup(@RequestParam("id") Long id) {
        consFollowupService.deleteConsFollowup(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得操作跟进")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('ecw:cons-followup:query')")
    public CommonResult<ConsFollowupBackVO> getConsFollowup(@RequestParam("id") Long id) {
        return success(consFollowupService.getConsFollowup(id));
    }

    @GetMapping("/list")
    @ApiOperation("获得操作跟进列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    @PreAuthorize("@ss.hasPermission('ecw:cons-followup:query')")
    public CommonResult<List<ConsFollowupBackVO>> getConsFollowupList(@RequestParam("ids") Collection<Long> ids) {
        List<ConsFollowupDO> list = consFollowupService.getConsFollowupList(ids);
        return success(ConsFollowupConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得操作跟进分页")
    @PreAuthorize("@ss.hasPermission('ecw:cons-followup:query')")
    public CommonResult<PageResult<ConsFollowupBackVO>> getConsFollowupPage(@Valid ConsFollowupQueryVO query, PageVO page) {
        return success(consFollowupService.getConsFollowupPage(query, page));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出操作跟进 Excel")
    @PreAuthorize("@ss.hasPermission('ecw:cons-followup:export')")
    @OperateLog(type = EXPORT)
    public void exportConsFollowupExcel(@Valid ConsFollowupQueryVO query,
                                        HttpServletResponse response) throws IOException {
        List<ConsFollowupDO> list = consFollowupService.getConsFollowupList(query);
        // 导出 Excel
        List<ConsFollowupBackVO> datas = ConsFollowupConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "操作跟进.xls", "数据", ConsFollowupBackVO.class, datas);
    }
}
