package cn.iocoder.yudao.module.order.controller.admin.consLanguageContent;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.order.convert.consLanguageContent.ConsLanguageContentConvert;
import cn.iocoder.yudao.module.order.dal.dataobject.consLanguageContent.ConsLanguageContentDO;
import cn.iocoder.yudao.module.order.service.consLanguageContent.ConsLanguageContentService;
import cn.iocoder.yudao.module.order.vo.consLanguageContent.ConsLanguageContentBackVO;
import cn.iocoder.yudao.module.order.vo.consLanguageContent.ConsLanguageContentCreateReqVO;
import cn.iocoder.yudao.module.order.vo.consLanguageContent.ConsLanguageContentQueryVO;
import cn.iocoder.yudao.module.order.vo.consLanguageContent.ConsLanguageContentUpdateReqVO;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;


@Validated
@RestController
@Api(tags = "管理后台 - 集运业务的多语言内容")
@RequestMapping("/ecw/cons-language-content")
public class ConsLanguageContentController {

    @Resource
    private ConsLanguageContentService consLanguageContentService;

    @PostMapping("/create")
    @ApiOperation("创建集运业务的多语言内容")
    @PreAuthorize("@ss.hasPermission('ecw:cons-language-content:create')")
    public CommonResult<Long> createConsLanguageContent(@Valid @RequestBody ConsLanguageContentCreateReqVO createReqVO) {
        return success(consLanguageContentService.createConsLanguageContent(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新集运业务的多语言内容")
    @PreAuthorize("@ss.hasPermission('ecw:cons-language-content:update')")
    public CommonResult<Boolean> updateConsLanguageContent(@Valid @RequestBody ConsLanguageContentUpdateReqVO updateReqVO) {
        consLanguageContentService.updateConsLanguageContent(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除集运业务的多语言内容")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('ecw:cons-language-content:delete')")
    public CommonResult<Boolean> deleteConsLanguageContent(@RequestParam("id") Long id) {
        consLanguageContentService.deleteConsLanguageContent(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得集运业务的多语言内容")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('ecw:cons-language-content:query')")
    public CommonResult<ConsLanguageContentBackVO> getConsLanguageContent(@RequestParam("id") Long id) {
        ConsLanguageContentDO consLanguageContent = consLanguageContentService.getConsLanguageContent(id);
        return success(ConsLanguageContentConvert.INSTANCE.convert(consLanguageContent));
    }

    @GetMapping("/list")
    @ApiOperation("获得集运业务的多语言内容列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    @PreAuthorize("@ss.hasPermission('ecw:cons-language-content:query')")
    public CommonResult<List<ConsLanguageContentBackVO>> getConsLanguageContentList(@RequestParam("ids") Collection<Long> ids) {
        List<ConsLanguageContentDO> list = consLanguageContentService.getConsLanguageContentList(ids);
        return success(ConsLanguageContentConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得集运业务的多语言内容分页")
    @PreAuthorize("@ss.hasPermission('ecw:cons-language-content:query')")
    public CommonResult<PageResult<ConsLanguageContentBackVO>> getConsLanguageContentPage(@Valid ConsLanguageContentQueryVO query, PageVO page) {
        PageResult<ConsLanguageContentDO> pageResult = consLanguageContentService.getConsLanguageContentPage(query, page);
        return success(ConsLanguageContentConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出集运业务的多语言内容 Excel")
    @PreAuthorize("@ss.hasPermission('ecw:cons-language-content:export')")
    @OperateLog(type = EXPORT)
    public void exportConsLanguageContentExcel(@Valid ConsLanguageContentQueryVO query,
              HttpServletResponse response) throws IOException {
        List<ConsLanguageContentDO> list = consLanguageContentService.getConsLanguageContentList(query);
        // 导出 Excel
        List<ConsLanguageContentBackVO> datas = ConsLanguageContentConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "集运业务的多语言内容.xls", "数据", ConsLanguageContentBackVO.class, datas);
    }
}
