package cn.iocoder.yudao.module.order.controller.admin.consLanguageTemplate;

import cn.iocoder.yudao.framework.i18n.core.I18nMessage;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.order.convert.consLanguageTemplate.ConsLanguageTemplateConvert;
import cn.iocoder.yudao.module.order.dal.dataobject.consLanguageTemplate.ConsLanguageTemplateDO;
import cn.iocoder.yudao.module.order.service.consLanguageTemplate.ConsLanguageTemplateService;
import cn.iocoder.yudao.module.order.vo.consLanguageTemplate.ConsLanguageTemplateBackVO;
import cn.iocoder.yudao.module.order.vo.consLanguageTemplate.ConsLanguageTemplateCreateReqVO;
import cn.iocoder.yudao.module.order.vo.consLanguageTemplate.ConsLanguageTemplateQueryVO;
import cn.iocoder.yudao.module.order.vo.consLanguageTemplate.ConsLanguageTemplateUpdateReqVO;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;

import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;

import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;

@Validated
@RestController
@Api(tags = "管理后台 - 集运业务的多语言模板")
@RequestMapping("/ecw/cons-language-template")
public class ConsLanguageTemplateController {

    @Resource
    private ConsLanguageTemplateService consLanguageTemplateService;

//    @PostMapping("/test")
//    @ApiOperation("测试")
//    public CommonResult<Boolean> createConsLanguageTemplate(@RequestBody Map<String, Object> map) {
//        return success(consLanguageTemplateService.useConsLanguageTemplate((Integer) map.get("businessNode"), (String) map.get("tableName"), (String) map.get("columnName"),
//                1L, (Map<String, Object>) map.get("templateParams")));
//    }

    @PostMapping("/create")
    @ApiOperation("创建集运业务的多语言模板")
    @PreAuthorize("@ss.hasPermission('ecw:cons-language-template:create')")
    public CommonResult<Long> createConsLanguageTemplate(@Valid @RequestBody ConsLanguageTemplateCreateReqVO createReqVO) {
        return success(consLanguageTemplateService.createConsLanguageTemplate(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新集运业务的多语言模板")
    @PreAuthorize("@ss.hasPermission('ecw:cons-language-template:update')")
    public CommonResult<Boolean> updateConsLanguageTemplate(@Valid @RequestBody ConsLanguageTemplateUpdateReqVO updateReqVO) {
        consLanguageTemplateService.updateConsLanguageTemplate(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除集运业务的多语言模板")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('ecw:cons-language-template:delete')")
    public CommonResult<Boolean> deleteConsLanguageTemplate(@RequestParam("id") Long id) {
        consLanguageTemplateService.deleteConsLanguageTemplate(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得集运业务的多语言模板")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('ecw:cons-language-template:query')")
    public CommonResult<ConsLanguageTemplateBackVO> getConsLanguageTemplate(@RequestParam("id") Long id) {
        ConsLanguageTemplateDO consLanguageTemplate = consLanguageTemplateService.getConsLanguageTemplate(id);
        return success(ConsLanguageTemplateConvert.INSTANCE.convert(consLanguageTemplate));
    }

    @GetMapping("/list")
    @ApiOperation("获得集运业务的多语言模板列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    @PreAuthorize("@ss.hasPermission('ecw:cons-language-template:query')")
    public CommonResult<List<ConsLanguageTemplateBackVO>> getConsLanguageTemplateList(@RequestParam("ids") Collection<Long> ids) {
        List<ConsLanguageTemplateDO> list = consLanguageTemplateService.getConsLanguageTemplateList(ids);
        return success(ConsLanguageTemplateConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得集运业务的多语言模板分页")
    @PreAuthorize("@ss.hasPermission('ecw:cons-language-template:query')")
    public CommonResult<PageResult<ConsLanguageTemplateBackVO>> getConsLanguageTemplatePage(@Valid ConsLanguageTemplateQueryVO query, PageVO page) {
        PageResult<ConsLanguageTemplateDO> pageResult = consLanguageTemplateService.getConsLanguageTemplatePage(query, page);
        return success(ConsLanguageTemplateConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出集运业务的多语言模板 Excel")
    @PreAuthorize("@ss.hasPermission('ecw:cons-language-template:export')")
    @OperateLog(type = EXPORT)
    public void exportConsLanguageTemplateExcel(@Valid ConsLanguageTemplateQueryVO query,
                                                HttpServletResponse response) throws IOException {
        List<ConsLanguageTemplateDO> list = consLanguageTemplateService.getConsLanguageTemplateList(query);
        // 导出 Excel
        List<ConsLanguageTemplateBackVO> datas = ConsLanguageTemplateConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "集运业务的多语言模板.xls", "数据", ConsLanguageTemplateBackVO.class, datas);
    }
}
