package cn.iocoder.yudao.module.order.controller.admin.consMedia;

import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.order.convert.consMedia.ConsMediaConvert;
import cn.iocoder.yudao.module.order.dal.dataobject.consMedia.ConsMediaDO;
import cn.iocoder.yudao.module.order.service.consMedia.ConsMediaService;
import cn.iocoder.yudao.module.order.vo.consMedia.ConsMediaBackVO;
import cn.iocoder.yudao.module.order.vo.consMedia.ConsMediaCreateReqVO;
import cn.iocoder.yudao.module.order.vo.consMedia.ConsMediaQueryVO;
import cn.iocoder.yudao.module.order.vo.consMedia.ConsMediaUpdateReqVO;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;
import javax.validation.constraints.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;


@Validated
@RestController
@Api(tags = "管理后台 - 集运包裹影像")
@RequestMapping("/ecw/cons-media")
public class ConsMediaController {

    @Resource
    private ConsMediaService consMediaService;

    @PostMapping("/create")
    @ApiOperation("创建集运包裹影像")
    public CommonResult<Long> createConsMedia(@Valid @RequestBody ConsMediaCreateReqVO createReqVO) {
        return success(consMediaService.createConsMedia(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新集运包裹影像")
    public CommonResult<Boolean> updateConsMedia(@Valid @RequestBody ConsMediaUpdateReqVO updateReqVO) {
        consMediaService.updateConsMedia(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除集运包裹影像")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<Boolean> deleteConsMedia(@RequestParam("id") Long id) {
        consMediaService.deleteConsMedia(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得集运包裹影像")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<ConsMediaBackVO> getConsMedia(@RequestParam("id") Long id) {
        ConsMediaDO consMedia = consMediaService.getConsMedia(id);
        return success(ConsMediaConvert.INSTANCE.convert(consMedia));
    }

    @GetMapping("/list")
    @ApiOperation("获得集运包裹影像列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    public CommonResult<List<ConsMediaBackVO>> getConsMediaList(@RequestParam("ids") Collection<Long> ids) {
        List<ConsMediaDO> list = consMediaService.getConsMediaList(ids);
        return success(ConsMediaConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得集运包裹影像分页")
    public CommonResult<PageResult<ConsMediaBackVO>> getConsMediaPage(@Valid ConsMediaQueryVO query, PageVO page) {
        PageResult<ConsMediaDO> pageResult = consMediaService.getConsMediaPage(query, page);
        return success(ConsMediaConvert.INSTANCE.convertPage(pageResult));
    }

}
