package cn.iocoder.yudao.module.order.controller.admin.consSpecialNeed;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.order.convert.consSpecialNeed.ConsSpecialNeedConvert;
import cn.iocoder.yudao.module.order.dal.dataobject.consSpecialNeed.ConsSpecialNeedDO;
import cn.iocoder.yudao.module.order.service.consSpecialNeed.ConsSpecialNeedService;
import cn.iocoder.yudao.module.order.vo.consSpecialNeed.ConsSpecialNeedBackVO;
import cn.iocoder.yudao.module.order.vo.consSpecialNeed.ConsSpecialNeedCreateReqVO;
import cn.iocoder.yudao.module.order.vo.consSpecialNeed.ConsSpecialNeedQueryVO;
import cn.iocoder.yudao.module.order.vo.consSpecialNeed.ConsSpecialNeedUpdateReqVO;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import io.swagger.annotations.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;


@Validated
@RestController
@Api(tags = "管理后台 - 包裹特需")
@RequestMapping("/ecw/cons-special-need")
public class ConsSpecialNeedController {

    @Resource
    private ConsSpecialNeedService consSpecialNeedService;

    @PostMapping("/create")
    @ApiOperation("创建包裹特需")
    public CommonResult<Boolean> createConsSpecialNeed(@RequestBody List<ConsSpecialNeedUpdateReqVO> updateReqVOList) {
        consSpecialNeedService.createConsSpecialNeed(updateReqVOList);
        return success(true);
    }

    @PutMapping("/update")
    @ApiOperation("更新包裹特需")
    public CommonResult<Boolean> updateConsSpecialNeed(@Valid @RequestBody ConsSpecialNeedUpdateReqVO updateReqVO) {
        consSpecialNeedService.updateConsSpecialNeed(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除包裹特需")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<Boolean> deleteConsSpecialNeed(@RequestParam("id") Long id) {
        consSpecialNeedService.deleteConsSpecialNeed(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得包裹特需")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<ConsSpecialNeedBackVO> getConsSpecialNeed(@RequestParam("id") Long id) {
        ConsSpecialNeedDO consSpecialNeed = consSpecialNeedService.getConsSpecialNeed(id);
        return success(ConsSpecialNeedConvert.INSTANCE.convert(consSpecialNeed));
    }

    @GetMapping("/getSpecialListByConsId")
    @ApiOperation("根据包裹id特需列表")
    public CommonResult<List<ConsSpecialNeedBackVO>> getSpecialListByConsId(@RequestParam("consId") Long consId) {
        List<ConsSpecialNeedDO> list = consSpecialNeedService.getSpecialListByConsId(consId);
        return success(ConsSpecialNeedConvert.INSTANCE.convertList(list));
    }
    @GetMapping("/selectAllSpecialListByConsId")
    @ApiOperation("根据包裹id特需列表（含删除）")
    public CommonResult<List<ConsSpecialNeedBackVO>> selectAllSpecialListByConsId(@RequestParam("consId") Long consId) {
        return success(consSpecialNeedService.selectAllSpecialListByConsId(consId));
    }

    @GetMapping("/list")
    @ApiOperation("获得包裹特需列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    public CommonResult<List<ConsSpecialNeedBackVO>> getConsSpecialNeedList(@RequestParam("ids") Collection<Long> ids) {
        List<ConsSpecialNeedDO> list = consSpecialNeedService.getConsSpecialNeedList(ids);
        return success(ConsSpecialNeedConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得包裹特需分页")
    public CommonResult<PageResult<ConsSpecialNeedBackVO>> getConsSpecialNeedPage(@Valid ConsSpecialNeedQueryVO query, PageVO page) {
        PageResult<ConsSpecialNeedDO> pageResult = consSpecialNeedService.getConsSpecialNeedPage(query, page);
        return success(ConsSpecialNeedConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出包裹特需 Excel")
    @OperateLog(type = EXPORT)
    public void exportConsSpecialNeedExcel(@Valid ConsSpecialNeedQueryVO query,
              HttpServletResponse response) throws IOException {
        List<ConsSpecialNeedDO> list = consSpecialNeedService.getConsSpecialNeedList(query);
        // 导出 Excel
        List<ConsSpecialNeedBackVO> datas = ConsSpecialNeedConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "包裹特需.xls", "数据", ConsSpecialNeedBackVO.class, datas);
    }
}
