package cn.iocoder.yudao.module.order.controller.admin.consTrackingRecord;

import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.order.convert.consTrackingRecord.ConsTrackingRecordConvert;
import cn.iocoder.yudao.module.order.dal.dataobject.consTrackingRecord.ConsTrackingRecordDO;
import cn.iocoder.yudao.module.order.service.consTrackingRecord.ConsTrackingRecordService;
import cn.iocoder.yudao.module.order.vo.consTrackingRecord.ConsTrackingRecordBackVO;
import cn.iocoder.yudao.module.order.vo.consTrackingRecord.ConsTrackingRecordCreateReqVO;
import cn.iocoder.yudao.module.order.vo.consTrackingRecord.ConsTrackingRecordQueryVO;
import cn.iocoder.yudao.module.order.vo.consTrackingRecord.ConsTrackingRecordUpdateReqVO;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;
import javax.validation.constraints.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;


@Validated
@RestController
@Api(tags = "管理后台 - 包裹动态跟踪")
@RequestMapping("/ecw/cons-tracking-record")
public class ConsTrackingRecordController {

    @Resource
    private ConsTrackingRecordService consTrackingRecordService;

    @PostMapping("/create")
    @ApiOperation("创建包裹动态跟踪")
    @PreAuthorize("@ss.hasPermission('ecw:cons-tracking-record:create')")
    public CommonResult<Long> createConsTrackingRecord(@Valid @RequestBody ConsTrackingRecordCreateReqVO createReqVO) {
        return success(consTrackingRecordService.createConsTrackingRecord(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新包裹动态跟踪")
    @PreAuthorize("@ss.hasPermission('ecw:cons-tracking-record:update')")
    public CommonResult<Boolean> updateConsTrackingRecord(@Valid @RequestBody ConsTrackingRecordUpdateReqVO updateReqVO) {
        consTrackingRecordService.updateConsTrackingRecord(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除包裹动态跟踪")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('ecw:cons-tracking-record:delete')")
    public CommonResult<Boolean> deleteConsTrackingRecord(@RequestParam("id") Long id) {
        consTrackingRecordService.deleteConsTrackingRecord(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得包裹动态跟踪")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('ecw:cons-tracking-record:query')")
    public CommonResult<ConsTrackingRecordBackVO> getConsTrackingRecord(@RequestParam("id") Long id) {
        ConsTrackingRecordDO consTrackingRecord = consTrackingRecordService.getConsTrackingRecord(id);
        return success(ConsTrackingRecordConvert.INSTANCE.convert(consTrackingRecord));
    }
    //获取包裹的动态跟踪
    @GetMapping("/getByConsId")
    @ApiOperation("获得包裹动态跟踪")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('ecw:cons-tracking-record:query')")
    public CommonResult<List<ConsTrackingRecordBackVO>> getConsTrackingRecordByConsId(@RequestParam("id") Long consId) {
        List<ConsTrackingRecordBackVO> consTrackingRecordList = consTrackingRecordService.getConsTrackingRecordByConsId(consId);
        return success(consTrackingRecordList);
    }

    @GetMapping("/list")
    @ApiOperation("获得包裹动态跟踪列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    @PreAuthorize("@ss.hasPermission('ecw:cons-tracking-record:query')")
    public CommonResult<List<ConsTrackingRecordBackVO>> getConsTrackingRecordList(@RequestParam("ids") Collection<Long> ids) {
        List<ConsTrackingRecordDO> list = consTrackingRecordService.getConsTrackingRecordList(ids);
        return success(ConsTrackingRecordConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得包裹动态跟踪分页")
    @PreAuthorize("@ss.hasPermission('ecw:cons-tracking-record:query')")
    public CommonResult<PageResult<ConsTrackingRecordBackVO>> getConsTrackingRecordPage(@Valid ConsTrackingRecordQueryVO query, PageVO page) {
        PageResult<ConsTrackingRecordDO> pageResult = consTrackingRecordService.getConsTrackingRecordPage(query, page);
        return success(ConsTrackingRecordConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出包裹动态跟踪 Excel")
    @PreAuthorize("@ss.hasPermission('ecw:cons-tracking-record:export')")
    @OperateLog(type = EXPORT)
    public void exportConsTrackingRecordExcel(@Valid ConsTrackingRecordQueryVO query,
              HttpServletResponse response) throws IOException {
        List<ConsTrackingRecordDO> list = consTrackingRecordService.getConsTrackingRecordList(query);
        // 导出 Excel
        List<ConsTrackingRecordBackVO> datas = ConsTrackingRecordConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "包裹动态跟踪.xls", "数据", ConsTrackingRecordBackVO.class, datas);
    }
}
