package cn.iocoder.yudao.module.order.controller.app.cons;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.util.code.CodeUtils;
import cn.iocoder.yudao.framework.i18n.core.I18nMessage;
import cn.iocoder.yudao.framework.i18n.core.LangEnum;
import cn.iocoder.yudao.framework.i18n.core.Languages;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.security.core.util.SecurityFrameworkUtils;
import cn.iocoder.yudao.module.customer.dal.dataobject.customer.CustomerDO;
import cn.iocoder.yudao.module.customer.service.customer.CustomerService;
import cn.iocoder.yudao.module.member.dal.dataobject.user.MemberUserDO;
import cn.iocoder.yudao.module.member.service.user.MemberUserService;
import cn.iocoder.yudao.module.order.convert.cons.ConsConvert;
import cn.iocoder.yudao.module.order.dal.dataobject.cons.ConsDO;
import cn.iocoder.yudao.module.order.service.cons.ConsService;
import cn.iocoder.yudao.module.order.service.cons.ConsServiceImpl;
import cn.iocoder.yudao.module.order.service.consItem.ConsItemService;
import cn.iocoder.yudao.module.order.vo.cons.*;
import cn.iocoder.yudao.module.order.vo.consItem.ConsItemBackVO;
import cn.iocoder.yudao.module.order.vo.consItem.ConsItemQueryVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;


@Validated
@RestController
@Api(tags = "web端 - app - 集运")
@RequestMapping("/order/cons")
@Slf4j
public class AppConsController {

    @Resource
    private ConsService consService;

    @Resource
    private ConsItemService consItemService;

    @Autowired
    private MemberUserService memberUserService;


    @PostMapping("/create")
    @ApiOperation("创建集运包裹")
    public CommonResult<Long> createCons(@Valid @RequestBody ConsCreateReqVO consCreateReqVO){
        // 根据用户id获取客户信息
        Long userId = SecurityFrameworkUtils.getLoginUser().getId();
        MemberUserDO memberUserDO = memberUserService.info(userId);
        // 设置客户id和客户编号参数
        consCreateReqVO.setCustomerId(memberUserDO.getCustomerId());
        consCreateReqVO.setCustomerNumber(memberUserDO.getCustomerCode());
        return success(consService.createCons(consCreateReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新集运包裹")
    public CommonResult<Boolean> updateCons(@Valid @RequestBody ConsUpdateReqVO updateReqVO){
        consService.updateCons(updateReqVO);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获取集运包裹")
    @ApiImplicitParam(name = "id", value = "包裹id", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<ConsBackVO> getCons(@RequestParam("id") Long id){

        // 获取包裹详情信息
        ConsBackVO consInfo = consService.getConsInfo(id);
        return success(consInfo);
    }

    @GetMapping("/express_no")
    @ApiOperation("获取快递单号")
    public CommonResult<String> getExpressNo(){
        // 生成快递单号
        String expressNo = CodeUtils.getCourierNumberByCons();
        // 判断快递单号是否存在则重新生成，不存在则返回
        while (consService.selectOne("express_no", expressNo) != null) {
            expressNo = CodeUtils.getCourierNumberByCons();
        }
        return success(expressNo);
    }

    @GetMapping("/page")
    @ApiOperation("获取我的集运包裹分页")
    public CommonResult<PageResult<ConsBackVO>> getConsPage(ConsQueryVO consQueryVO, PageVO pageVO){
        PageResult<ConsBackVO> myConsPage = consService.getMyConsPage(consQueryVO, pageVO);
        return success(myConsPage);
    }

}
